@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/denote-silo
-;; Version: 0.1.2
+;; Version: 0.2.0
 ;; Package-Requires: ((emacs "28.1") (denote "4.0.0"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -45,8 +45,7 @@
   :link '(url-link :tag "Denote homepage" "https://protesilaos.com/emacs/denote")
   :link '(url-link :tag "Denote Silo homepage" "https://protesilaos.com/emacs/denote-silo"))
 
-(defcustom denote-silo-directories
-  `(,denote-directory)
+(defcustom denote-silo-directories (list denote-directory)
   "List of file paths pointing to Denote silos.
 Each file path points to a directory, which takes the same value
 as the variable `denote-directory'."
